%global libnghttp2_version %(pkg-config --modversion libnghttp2 2>/dev/null || echo 0)
%global libpsl_version %(pkg-config --modversion libpsl 2>/dev/null || echo 0)
%global libssh_version %(pkg-config --modversion libssh 2>/dev/null || echo 0)
%global openssl_version %({ pkg-config --modversion openssl 2>/dev/null || echo 0;} | sed 's|-|-0.|')
%global _configure ../configure

Summary: A utility for getting files from remote servers (FTP, HTTP, and others)
Name: curl
Version: 8.4.0
Release: 5%{?dist}
License: MIT
URL: https://curl.se/
Source0: https://curl.se/download/curl-%{version}.tar.xz

Patch0001: CVE-2023-46218.patch
Patch0002: CVE-2023-46219.patch
Patch0003: CVE-2024-2004.patch
Patch0004: CVE-2024-2398.patch
Patch3000: 0101-curl-7.32.0-multilib.patch
Patch3001: 0102-curl-7.84.0-test3026.patch
Patch3002: 0104-curl-7.88.0-tests-warnings.patch

BuildRequires: automake make brotli-devel coreutils gcc groff krb5-devel
BuildRequires: libidn2-devel libnghttp2-devel libpsl-devel libssh-devel libtool
BuildRequires: openldap-devel openssh-clients openssh-server openssl-devel
BuildRequires: pkgconfig python-unversioned-command python3-devel
BuildRequires: sed zlib-devel gnutls-utils nghttp2 perl-interpreter
BuildRequires: perl(IO::Compress::Gzip) perl(Getopt::Long) perl(Pod::Usage)
BuildRequires: perl(Cwd) perl(Digest::MD5) perl(Digest::SHA) perl(File::Basename)
BuildRequires: perl(File::Copy) perl(IPC::Open2) perl(MIME::Base64) perl(Time::Local)
BuildRequires: perl(Time::HiRes) perl(vars) perl(B) perl(base) perl(constant)
BuildRequires: perl(List::Util) perl(Memoize) perl(POSIX) perl(Storable)
BuildRequires: perl(Exporter) perl(File::Spec) perl(strict) perl(warnings)
%ifarch x86_64
BuildRequires: valgrind
%endif

Requires: libcurl >= %{version}-%{release}

Provides: curl-full = %{version}-%{release} webclient

%description
curl is a command line tool for transferring data with URL syntax which supports
DICT, FILE, FTP, FTPS, GOPHER, GOPHERS, HTTP, HTTPS, IMAP, IMAPS, LDAP, LDAPS, MQTT,
POP3, POP3S, RTMP, RTMPS, RTSP, SCP, SFTP, SMB, SMBS, SMTP, SMTPS, TELNET and TFTP.
curl supports SSL certificates, HTTP POST, HTTP PUT, FTP uploading, HTTP form based upload,
proxies, HTTP/2, HTTP/3, cookies, user+password authentication (Basic, Plain, Digest, CRAM-MD5,
SCRAM-SHA, NTLM, Negotiate and Kerberos), file transfer resume, proxy tunneling and more.

%package -n libcurl
Summary: A library for getting files from web servers
Requires: libnghttp2 >= %{libnghttp2_version}
Requires: libpsl >= %{libpsl_version}
Requires: libssh >= %{libssh_version}
Requires: openssl-libs >= %{openssl_version}
Provides: libcurl-full = %{version}-%{release}

%description -n libcurl
libcurl is a free and easy-to-use client-side URL transfer library, supporting DICT,
FILE, FTP, FTPS, GOPHER, GOPHERS, HTTP, HTTPS, IMAP, IMAPS, LDAP, LDAPS, MQTT, POP3,
POP3S, RTMP, RTMPS, RTSP, SCP, SFTP, SMB, SMBS, SMTP, SMTPS, TELNET and TFTP. libcurl
supports SSL certificates, HTTP POST, HTTP PUT, FTP uploading, HTTP form based upload,
proxies, HTTP/2, HTTP/3, cookies, user+password authentication (Basic, Digest, NTLM,
Negotiate, Kerberos), file transfer resume, http proxy tunneling and more!

%package -n libcurl-devel
Summary: Files needed for building applications with libcurl
Requires: libnghttp2 >= %{libnghttp2_version}
Requires: libcurl = %{version}-%{release}
Provides: curl-devel = %{version}-%{release}

%description -n libcurl-devel
The libcurl-devel package includes header files and libraries necessary for
developing programs which use the libcurl library. It contains the API
documentation of the library, too.

%prep
%autosetup -p1

printf "1112\n1455\n1184\n1801\n" >> tests/data/DISABLED
sed -e 's|^35$|35,52|' -i tests/data/test323
(
    { set +x; } 2>/dev/null
    cmd="sed -e 's|ip6-localhost|localhost6|' -i tests/data/test[0-9]*"
    printf "+ %s\n" "$cmd" >&2
    eval "$cmd"
)

autoreconf -fiv

%build
mkdir build-full
(
    cd build-full
    %configure                          \
        --cache-file=../config.cache    \
        --disable-static                \
        --enable-hsts                   \
        --enable-ipv6                   \
        --enable-symbol-hiding          \
        --enable-threaded-resolver      \
        --enable-dict                   \
        --enable-gopher                 \
        --enable-imap                   \
        --enable-ldap                   \
        --enable-ldaps                  \
        --enable-manual                 \
        --enable-mqtt                   \
        --enable-ntlm                   \
        --enable-ntlm-wb                \
        --enable-pop3                   \
        --enable-rtsp                   \
        --enable-smb                    \
        --enable-smtp                   \
        --enable-telnet                 \
        --enable-tftp                   \
        --enable-tls-srp                \
        --with-brotli                   \
        --with-libidn2                  \
        --with-libpsl                   \
        --with-libssh                   \
        --without-zstd                  \
        --with-gssapi                   \
        --with-nghttp2                  \
        --with-ssl                      \
        --with-ca-bundle=%{_sysconfdir}/pki/tls/certs/ca-bundle.crt
)

sed -e 's/^runpath_var=.*/runpath_var=/' \
    -e 's/^hardcode_libdir_flag_spec=".*"$/hardcode_libdir_flag_spec=""/' \
    -i build-full/libtool

%make_build V=1 -C build-full

%install

rm -f ${RPM_BUILD_ROOT}%{_libdir}/libcurl.{la,so}

install -d $RPM_BUILD_ROOT%{_datadir}/aclocal
install -m 644 docs/libcurl/libcurl.m4 $RPM_BUILD_ROOT%{_datadir}/aclocal

cd build-full
%make_install

LD_LIBRARY_PATH="$RPM_BUILD_ROOT%{_libdir}:$LD_LIBRARY_PATH" %make_install -C scripts

rm -rf ${RPM_BUILD_ROOT}%{_datadir}/fish
rm -f ${RPM_BUILD_ROOT}%{_libdir}/libcurl.la

%check

%make_build V=1 -C build-full/tests

export OPENSSL_SYSTEM_CIPHERS_OVERRIDE=XXX
export OPENSSL_CONF=
export srcdir=../../tests
unset DEBUGINFOD_URLS

cd build-full
export LD_LIBRARY_PATH="${PWD}/lib/.libs"
cd tests
perl -I../../tests ../../tests/runtests.pl -a -p -v '!flaky'

%post -n libcurl -p /sbin/ldconfig

%postun -n libcurl -p /sbin/ldconfig

%files
%doc CHANGES README
%doc docs/BUGS.md docs/FAQ docs/FEATURES.md docs/TODO
%doc docs/TheArtOfHttpScripting.md
%{_bindir}/curl
%{_datadir}/zsh
%{_mandir}/man1/curl.1*

%files -n libcurl
%license COPYING
%{_libdir}/libcurl.so.4
%{_libdir}/libcurl.so.4.[0-9].[0-9]

%files -n libcurl-devel
%doc docs/examples/*.c docs/examples/Makefile.example docs/INTERNALS.md
%doc docs/CONTRIBUTE.md docs/libcurl/ABI.md
%{_bindir}/curl-config*
%{_includedir}/curl
%{_libdir}/*.so
%{_libdir}/pkgconfig/*.pc
%{_datadir}/aclocal/libcurl.m4
%{_mandir}/man1/curl-config.1*
%{_mandir}/man3/*

%changelog
* Fri Mar 29 2024 Miaojun Dong <zoedong@tencent.com> - 8.4.0-5
- Fix CVE-2024-2004, CVE-2023-46219

* Mon Dec 11 2023 Miaojun Dong <zoedong@tencent.com> - 8.4.0-4
- Fix CVE-2023-46218, CVE-2023-46219

* Tue Nov 14 2023 Miaojun Dong <zoedong@tencent.com> - 8.4.0-3
- Force versioned libnghttp2 dependency on libcurl

* Thu Oct 12 2023 Miaojun Dong <zoedong@tencent.com> - 8.4.0-2
- Rebuild for curl-8.4.0

* Wed Oct 11 2023 Miaojun Dong <zoedong@tencent.com> - 8.4.0-1
- Bump version to 8.4.0
- Fix CVE-2023-38545 CVE-2023-38546

* Fri Sep 08 2023 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 8.2.1-3
- Rebuilt for OpenCloudOS Stream 23.09

* Tue Aug 22 2023 cunshunxia <cunshunxia@tencent.com> - 8.2.1-2
- Rebuilt for libssh 0.10.5

* Thu Jul 27 2023 kianli <kianli@tencent.com> - 8.2.1-1
- Upgrade to 8.2.1

* Fri Apr 28 2023 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 7.83.1-4
- Rebuilt for OpenCloudOS Stream 23.05

* Fri Mar 31 2023 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 7.83.1-3
- Rebuilt for OpenCloudOS Stream 23

* Wed Feb 15 2023 cunshunxia <cunshunxia@tencent.com> - 7.83.1-2
- remove requirement on python-impacket.

* Mon May 23 2022 Minjie HUANG <jackmjhuang@tencent.com> - 7.83.1-1
- Initial build.
